@@ -130,13 +130,12 @@ commonprep () {
         fi
     fi
 
-    CxxUrlVER="0.3"
+    CxxUrlVER="eaf46c0207df24853a238d4499e7f4426d9d234c"
     if [ -e "build/CxxUrl-${CxxUrlVER}.tar.gz" ]; then
         echo "Found existing CxxUrl tarball..."
     else
         echo "Retrieving CxxUrl ${CxxUrlVER} submodule..."
-        # The dir that results from untar doesn't have the v
-        curl -L https://github.com/chmike/CxxUrl/archive/refs/tags/v${CxxUrlVER}.tar.gz > build/CxxUrl-${CxxUrlVER}.tar.gz
+        curl -L https://github.com/chmike/CxxUrl/archive/${CxxUrlVER}.tar.gz > build/CxxUrl-${CxxUrlVER}.tar.gz
         if [ $? -ne 0 ]; then
             echo "ERROR: CxxUrl tarball retrieval failed..."
             exit 1
@@ -170,14 +169,10 @@ movecrud () {
         rmdir dep/RtspServer
         mv -f RtspServer-${RTSPVER} dep/RtspServer
     fi
-    if [ -e "dep/CxxUrl/CMakeLists.txt" ]; then
-        echo "CxxUrl already installed..."
-    else
-        echo "Unpacking CxxUrl..."
-        tar -xzf build/CxxUrl-${CxxUrlVER}.tar.gz
-        rmdir dep/CxxUrl
-        mv -f CxxUrl-${CxxUrlVER} dep/CxxUrl
-    fi
+    echo "Unpacking CxxUrl..."
+    tar -xzf build/CxxUrl-${CxxUrlVER}.tar.gz
+    rm -r dep/CxxUrl
+    mv -f CxxUrl-${CxxUrlVER} dep/CxxUrl
 }
 
 # previously part of installzm.sh
