@@ -43,7 +43,7 @@ monitorData[monitorData.length] = {
   'height':<?php echo $m->ViewHeight() ?>,
   'RTSP2WebEnabled':<?php echo $m->RTSP2WebEnabled() ?>,
   'DefaultPlayer':'<?php echo $m->DefaultPlayer() ?>',
-  'RTSP2WebStream':'<?php echo $m->RTSP2WebStream() ?>',
+  'StreamChannel':'<?php echo $m->StreamChannel() ?>',
   'Go2RTCEnabled': <?php echo $m->Go2RTCEnabled() ?>,
   'SecondPath':'<?php echo $m->SecondPath() ?>',
   'janusEnabled':<?php echo $m->JanusEnabled() ?>,
